==> tencentcloud-sdk-java-3.0.32-sources.jar: com/tencentcloudapi/live/v20180801/models/DescribeLivePushAuthKeyResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.live.v20180801.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeLivePushAuthKeyResponse  extends AbstractModel{

    /**
    * 推流鉴权key信息。
    */
    @SerializedName("PushAuthKeyInfo")
    @Expose
    private PushAuthKeyInfo PushAuthKeyInfo;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * 获取推流鉴权key信息。
     * @return PushAuthKeyInfo 推流鉴权key信息。
     */
    public PushAuthKeyInfo getPushAuthKeyInfo() {
        return this.PushAuthKeyInfo;
    }

    /**
     * 设置推流鉴权key信息。
     * @param PushAuthKeyInfo 推流鉴权key信息。
     */
    public void setPushAuthKeyInfo(PushAuthKeyInfo PushAuthKeyInfo) {
        this.PushAuthKeyInfo = PushAuthKeyInfo;
    }

    /**
     * 获取唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * 设置唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    /**
     * 内部实现，用户禁止调用
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamObj(map, prefix + "PushAuthKeyInfo.", this.PushAuthKeyInfo);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-3.1.135-sources.jar: com/tencentcloudapi/live/v20180801/models/DescribeLivePushAuthKeyResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.live.v20180801.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeLivePushAuthKeyResponse extends AbstractModel{

    /**
    * 推流鉴权key信息。
    */
    @SerializedName("PushAuthKeyInfo")
    @Expose
    private PushAuthKeyInfo PushAuthKeyInfo;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 推流鉴权key信息。 
     * @return PushAuthKeyInfo 推流鉴权key信息。
     */
    public PushAuthKeyInfo getPushAuthKeyInfo() {
        return this.PushAuthKeyInfo;
    }

    /**
     * Set 推流鉴权key信息。
     * @param PushAuthKeyInfo 推流鉴权key信息。
     */
    public void setPushAuthKeyInfo(PushAuthKeyInfo PushAuthKeyInfo) {
        this.PushAuthKeyInfo = PushAuthKeyInfo;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamObj(map, prefix + "PushAuthKeyInfo.", this.PushAuthKeyInfo);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
